@@ -60,6 +60,10 @@ def save_csv_crd(operatorName, output):
     crds[operatorName] = YAML_DELIMITER + YAML_DELIMITER.join(odocs[1:])
 
 
+def save_crd(operatorName, output):
+    crds[operatorName] = output
+
+
 def split_crds(operatorName, crd_data):
     crds = crd_data.split('---')
     idx = 1
@@ -108,7 +112,12 @@ def write_csvs_crds():
     writeTofile(imagelistfile, getAllImages())
 
 
-def run_pod(operatorArgs, image_pull_url, operatorName, nvr):
+def run_pod(
+        operatorArgs,
+        image_pull_url,
+        operatorName, nvr,
+        entrypoint="/usr/bin/csv-generator",
+        crds_only=False):
     pod_name = nvr_to_pod_name(nvr)
     ocArgs = [
         "oc",
@@ -121,14 +130,14 @@ def run_pod(operatorArgs, image_pull_url, operatorName, nvr):
         "--restart=Never",
         "--command",
         "--",
-        "/usr/bin/csv-generator",
+        entrypoint,
     ]
 
     dockerArgs = [
         "docker",
         "run",
         "--rm",
-        "--entrypoint=/usr/bin/csv-generator",
+        "--entrypoint=%s" % entrypoint,
         image_pull_url,
     ]
 
@@ -170,12 +179,21 @@ def run_pod(operatorArgs, image_pull_url, operatorName, nvr):
                 cmd_result.stderr.decode("utf-8")
             )
         )
-
-    logger.info("Generated CSV and CRD from %s" % image_pull_url)
-    logger.info(
-        "%s CSV+CRD %s=" % (operatorName, cmd_result.stdout.decode("utf-8"))
-    )
-    save_csv_crd(operatorName, cmd_result.stdout.decode("utf-8"))
+    if not crds_only:
+        logger.info("Generated CSV and CRDs from %s" % image_pull_url)
+        logger.info(
+            "%s CSV+CRD %s=" % (
+                operatorName,
+                cmd_result.stdout.decode("utf-8")
+            )
+        )
+        save_csv_crd(operatorName, cmd_result.stdout.decode("utf-8"))
+    else:
+        logger.info("Generated CRDs from %s" % image_pull_url)
+        logger.info(
+            "%s CRDs %s=" % (operatorName, cmd_result.stdout.decode("utf-8"))
+        )
+        save_crd(operatorName, cmd_result.stdout.decode("utf-8"))
 
 
 def get_env_var(envVar):
@@ -195,7 +213,7 @@ def getBuildInfo(envVar):
 def getAllImages():
     if use_sha_digest():
         return ','.join([
-            getShaPullURL(envk)
+            getShaPullURL(envk)+'|'+getPullURL(envk)
             for envk in os.environ
             if envk.endswith('_BUILD_INFO_JSON')
         ])
@@ -220,6 +238,10 @@ def use_sha_digest():
     return False
 
 
+def get_product_version():
+    return os.getenv('CPAAS_PRODUCT_VERSION', '0.0.0')
+
+
 def getImageVersion(envVar):
     buildInfo = getBuildInfo(envVar)
     if use_sha_digest():
@@ -388,14 +410,13 @@ def create_cdi_csv():
     variableName = "VIRT_CDI_OPERATOR_BUILD_INFO_JSON"
     buildInfo = getBuildInfo(variableName)
     pullURL = getImageURL(variableName)
-    operator_version = getImageVersion(variableName)
 
     args = [
         "--csv-version=%s" % new_csv_version,
         "--replaces-csv-version=%s" % old_csv_version,
         "--namespace=" + NAMESPACE_PLACEHOLDER,
         "--cdi-logo-base64=logo",
-        "--operator-version=%s" % operator_version,
+        "--operator-version=%s" % 'v' + get_product_version(),
         "--operator-image=%s" % pullURL,
         "--controller-image=%s" % getImageURL(
             "VIRT_CDI_CONTROLLER_BUILD_INFO_JSON"
@@ -478,9 +499,30 @@ def create_all_csvs():
     create_hpp_csv()
 
 
+def create_hco_crds():
+    if get_product_version()[:3] != "2.2":
+        logger.info("Creating HCO CRDs.....")
+        buildInfo = getBuildInfo(
+            "HYPERCONVERGED_CLUSTER_OPERATOR_BUILD_INFO_JSON"
+        )
+        args = [
+            "--output-mode=CRDs",
+            "--namespace=%s" % NAMESPACE_PLACEHOLDER,
+        ]
+        run_pod(
+            args,
+            get_env_var("HYPERCONVERGED_CLUSTER_OPERATOR_IMAGE_PULL_URL"),
+            buildInfo["name"],
+            buildInfo["nvr"],
+            entrypoint="/usr/local/bin/csv-merger",
+            crds_only=True,
+        )
+
+
 def nvr_to_pod_name(nvr):
     return nvr.lower().replace('.', '-') + '-pod'
 
 
 create_all_csvs()
+create_hco_crds()
 write_csvs_crds()
