@@ -13,10 +13,19 @@ if CPAAS_PRODUCT_VERSION == '2.2.0':
     DEFAULT_ERRATA = '45581'
     DEFAULT_CHANNEL = "RHEL-8-CNV-2.2"
     ADDITIONAL_CHANNEL = "RHEL-7-CNV-2.2"
+elif CPAAS_PRODUCT_VERSION == '2.2.1':
+    DEFAULT_ERRATA = '51253'
+    DEFAULT_CHANNEL = "RHEL-8-CNV-2.2"
+    ADDITIONAL_CHANNEL = "RHEL-7-CNV-2.2"
 elif CPAAS_PRODUCT_VERSION == '2.3.0':
     DEFAULT_ERRATA = '48747'
     DEFAULT_CHANNEL = "RHEL-8-CNV-2.3"
     ADDITIONAL_CHANNEL = "RHEL-7-CNV-2.3"
+elif CPAAS_PRODUCT_VERSION == '2.4.0':
+    DEFAULT_ERRATA = '51552'
+    DEFAULT_CHANNEL = "RHEL-8-CNV-2.4"
+    ADDITIONAL_CHANNEL = "RHEL-7-CNV-2.4"
+
 else:
     raise RuntimeError("Unsupported release: {r}".format(r=CPAAS_PRODUCT_VERSION))
 
